{
    "$graph": [
        {
            "label": "Map HMM Hits",
            "class": "CommandLineTool",
            "baseCommand": "bacterial_hit_mapping",
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-align-fmt"
                    },
                    "id": "#bacterial_hit_mapping.cwl/align_fmt"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "Directory"
                    },
                    "inputBinding": {
                        "prefix": "-asn-cache",
                        "itemSeparator": ","
                    },
                    "id": "#bacterial_hit_mapping.cwl/asn_cache"
                },
                {
                    "type": "float",
                    "inputBinding": {
                        "prefix": "-expansion-ratio"
                    },
                    "id": "#bacterial_hit_mapping.cwl/expansion_ratio"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-aligns"
                    },
                    "id": "#bacterial_hit_mapping.cwl/hmm_hits"
                },
                {
                    "type": "boolean",
                    "inputBinding": {
                        "prefix": "-no-compart"
                    },
                    "id": "#bacterial_hit_mapping.cwl/no_compart"
                },
                {
                    "type": "boolean",
                    "inputBinding": {
                        "prefix": "-nogenbank"
                    },
                    "id": "#bacterial_hit_mapping.cwl/nogenbank"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "mapped-hmm-hits.asn",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#bacterial_hit_mapping.cwl/outfile"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#bacterial_hit_mapping.cwl/proteins"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "id": "#bacterial_hit_mapping.cwl/seq_cache"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-sequences"
                    },
                    "id": "#bacterial_hit_mapping.cwl/sequences"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "id": "#bacterial_hit_mapping.cwl/unicoll_cache"
                }
            ],
            "id": "#bacterial_hit_mapping.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.outfile)"
                    },
                    "id": "#bacterial_hit_mapping.cwl/aligns"
                }
            ]
        },
        {
            "label": "Bacterial Annotation, pass 2, blastp-based functional annotation (first pass)",
            "class": "Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "label": "Get ORFs/outseq",
                    "type": "File",
                    "id": "#main/annotation"
                },
                {
                    "label": "Name of blast_rules_db",
                    "type": "string",
                    "id": "#main/blast_rules_db"
                },
                {
                    "label": "Get BLAST Rules db const",
                    "type": "Directory",
                    "id": "#main/blast_rules_db_dir"
                },
                {
                    "label": "Create identification BLASTdb",
                    "type": "Directory",
                    "id": "#main/identification_db_dir"
                },
                {
                    "label": "Extract ORF Proteins/lds2",
                    "type": "File",
                    "id": "#main/lds2"
                },
                {
                    "label": "Extract ORF Proteins/prot_ids",
                    "type": "File",
                    "id": "#main/prot_ids_A"
                },
                {
                    "label": "Get off-frame ORFs/prot_ids",
                    "type": "File",
                    "id": "#main/prot_ids_B1"
                },
                {
                    "label": "AntiFam tainted proteins I/oseqids",
                    "type": "File",
                    "id": "#main/prot_ids_B2"
                },
                {
                    "label": "Extract ORF Proteins/proteins",
                    "type": "File",
                    "id": "#main/proteins"
                },
                {
                    "type": "string",
                    "id": "#main/scatter_gather_nchunks"
                },
                {
                    "type": "Directory",
                    "id": "#main/sequence_cache"
                },
                {
                    "type": "Directory",
                    "id": "#main/unicoll_cache"
                }
            ],
            "outputs": [
                {
                    "label": "goes to protein_alignment/Seed Search Compartments/compartments",
                    "type": "File",
                    "outputSource": "#main/Map_Naming_Hits/aligns",
                    "id": "#main/aligns"
                }
            ],
            "steps": [
                {
                    "label": "Find Naming Protein Hits I",
                    "run": "#tt_blastp_wnode_naming.cwl",
                    "in": [
                        {
                            "default": "subject",
                            "id": "#main/Find_Naming_Protein_Hits_I/affinity"
                        },
                        {
                            "default": "score>0 && pct_identity_gapopen_only > 35",
                            "id": "#main/Find_Naming_Protein_Hits_I/align_filter"
                        },
                        {
                            "default": false,
                            "id": "#main/Find_Naming_Protein_Hits_I/allow_intersection"
                        },
                        {
                            "source": [
                                "#main/sequence_cache",
                                "#main/unicoll_cache"
                            ],
                            "id": "#main/Find_Naming_Protein_Hits_I/asn_cache"
                        },
                        {
                            "default": [
                                "blastdb",
                                "blast_rules_db"
                            ],
                            "id": "#main/Find_Naming_Protein_Hits_I/blastdb"
                        },
                        {
                            "source": [
                                "#main/blast_rules_db_dir",
                                "#main/identification_db_dir"
                            ],
                            "linkMerge": "merge_flattened",
                            "id": "#main/Find_Naming_Protein_Hits_I/blastdb_dir"
                        },
                        {
                            "default": "F",
                            "id": "#main/Find_Naming_Protein_Hits_I/comp_based_stats"
                        },
                        {
                            "default": false,
                            "id": "#main/Find_Naming_Protein_Hits_I/compart"
                        },
                        {
                            "default": "6000000000",
                            "id": "#main/Find_Naming_Protein_Hits_I/dbsize"
                        },
                        {
                            "default": 0.1,
                            "id": "#main/Find_Naming_Protein_Hits_I/evalue"
                        },
                        {
                            "default": 20,
                            "id": "#main/Find_Naming_Protein_Hits_I/extra_coverage"
                        },
                        {
                            "source": [
                                "#main/Remove_off_frame_ORFs/output"
                            ],
                            "linkMerge": "merge_flattened",
                            "id": "#main/Find_Naming_Protein_Hits_I/ids"
                        },
                        {
                            "source": "#main/lds2",
                            "id": "#main/Find_Naming_Protein_Hits_I/lds2"
                        },
                        {
                            "default": 10000,
                            "id": "#main/Find_Naming_Protein_Hits_I/max_batch_length"
                        },
                        {
                            "default": 1,
                            "id": "#main/Find_Naming_Protein_Hits_I/max_jobs"
                        },
                        {
                            "default": 50,
                            "id": "#main/Find_Naming_Protein_Hits_I/max_target_seqs"
                        },
                        {
                            "default": true,
                            "id": "#main/Find_Naming_Protein_Hits_I/no_merge"
                        },
                        {
                            "default": true,
                            "id": "#main/Find_Naming_Protein_Hits_I/nogenbank"
                        },
                        {
                            "default": "asn-binary",
                            "id": "#main/Find_Naming_Protein_Hits_I/ofmt"
                        },
                        {
                            "source": "#main/proteins",
                            "id": "#main/Find_Naming_Protein_Hits_I/proteins"
                        },
                        {
                            "source": "#main/scatter_gather_nchunks",
                            "id": "#main/Find_Naming_Protein_Hits_I/scatter_gather_nchunks"
                        },
                        {
                            "default": "no",
                            "id": "#main/Find_Naming_Protein_Hits_I/seg"
                        },
                        {
                            "default": 21,
                            "id": "#main/Find_Naming_Protein_Hits_I/threshold"
                        },
                        {
                            "default": 10,
                            "id": "#main/Find_Naming_Protein_Hits_I/top_by_score"
                        },
                        {
                            "default": 6,
                            "id": "#main/Find_Naming_Protein_Hits_I/word_size"
                        }
                    ],
                    "out": [
                        "#main/Find_Naming_Protein_Hits_I/blast_align"
                    ],
                    "id": "#main/Find_Naming_Protein_Hits_I"
                },
                {
                    "label": "Map Naming Hits",
                    "run": "#bacterial_hit_mapping.cwl",
                    "in": [
                        {
                            "default": "seq-align-set",
                            "id": "#main/Map_Naming_Hits/align_fmt"
                        },
                        {
                            "source": [
                                "#main/sequence_cache",
                                "#main/unicoll_cache"
                            ],
                            "id": "#main/Map_Naming_Hits/asn_cache"
                        },
                        {
                            "default": 1.1,
                            "id": "#main/Map_Naming_Hits/expansion_ratio"
                        },
                        {
                            "source": "#main/Find_Naming_Protein_Hits_I/blast_align",
                            "id": "#main/Map_Naming_Hits/hmm_hits"
                        },
                        {
                            "default": false,
                            "id": "#main/Map_Naming_Hits/no_compart"
                        },
                        {
                            "default": true,
                            "id": "#main/Map_Naming_Hits/nogenbank"
                        },
                        {
                            "source": "#main/proteins",
                            "id": "#main/Map_Naming_Hits/proteins"
                        },
                        {
                            "source": "#main/annotation",
                            "id": "#main/Map_Naming_Hits/sequences"
                        }
                    ],
                    "out": [
                        "#main/Map_Naming_Hits/aligns"
                    ],
                    "id": "#main/Map_Naming_Hits"
                },
                {
                    "label": "Remove off-frame ORFs",
                    "run": "#set_operation.cwl",
                    "in": [
                        {
                            "source": [
                                "#main/prot_ids_A"
                            ],
                            "linkMerge": "merge_flattened",
                            "id": "#main/Remove_off_frame_ORFs/A"
                        },
                        {
                            "source": [
                                "#main/prot_ids_B1",
                                "#main/prot_ids_B2"
                            ],
                            "linkMerge": "merge_flattened",
                            "id": "#main/Remove_off_frame_ORFs/B"
                        },
                        {
                            "default": "-",
                            "id": "#main/Remove_off_frame_ORFs/operation"
                        }
                    ],
                    "out": [
                        "#main/Remove_off_frame_ORFs/output"
                    ],
                    "id": "#main/Remove_off_frame_ORFs"
                }
            ],
            "id": "#main"
        },
        {
            "label": "cluster_blastp_wnode",
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entry": "${ var cs=0; var s=inputs.blastdb_dir.length-1; var as = cs; if(as >= s) {as = s }; return inputs.blastdb_dir[as]; }",
                            "writable": false
                        },
                        {
                            "entry": "${ var cs=1; var s=inputs.blastdb_dir.length-1; var as = cs; if(as >= s) {as = s }; return inputs.blastdb_dir[as]; }",
                            "writable": false
                        },
                        {
                            "entry": "${ var cs=0; var s=inputs.asn_cache.length-1; var as = cs; if(as >= s) {as = s }; return inputs.asn_cache[as]; }",
                            "writable": false
                        },
                        {
                            "entry": "${ var cs=1; var s=inputs.asn_cache.length-1; var as = cs; if(as >= s) {as = s }; return inputs.asn_cache[as]; }",
                            "writable": false
                        },
                        {
                            "entry": "$(inputs.lds2)",
                            "writable": true
                        },
                        {
                            "entry": "$(inputs.proteins)",
                            "writable": false
                        }
                    ]
                }
            ],
            "baseCommand": "cluster_blastp_wnode",
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-align_filter"
                    },
                    "id": "#cluster_blastp_wnode.cwl/align_filter"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "-allow-intersection"
                    },
                    "id": "#cluster_blastp_wnode.cwl/allow_intersection"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "Directory"
                    },
                    "inputBinding": {
                        "prefix": "-asn-cache",
                        "itemSeparator": ","
                    },
                    "id": "#cluster_blastp_wnode.cwl/asn_cache"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-backlog"
                    },
                    "id": "#cluster_blastp_wnode.cwl/backlog"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "Directory"
                    },
                    "id": "#cluster_blastp_wnode.cwl/blastdb_dir"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-comp_based_stats"
                    },
                    "id": "#cluster_blastp_wnode.cwl/comp_based_stats"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "-compart"
                    },
                    "id": "#cluster_blastp_wnode.cwl/compart"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-dbsize"
                    },
                    "id": "#cluster_blastp_wnode.cwl/dbsize"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-delay"
                    },
                    "id": "#cluster_blastp_wnode.cwl/delay"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "prefix": "-evalue"
                    },
                    "id": "#cluster_blastp_wnode.cwl/evalue"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-extra-coverage"
                    },
                    "id": "#cluster_blastp_wnode.cwl/extra_coverage"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-input-jobs"
                    },
                    "id": "#cluster_blastp_wnode.cwl/input_jobs"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-lds2"
                    },
                    "id": "#cluster_blastp_wnode.cwl/lds2"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-max-jobs"
                    },
                    "id": "#cluster_blastp_wnode.cwl/max_jobs"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-max_target_seqs"
                    },
                    "id": "#cluster_blastp_wnode.cwl/max_target_seqs"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "-no-merge"
                    },
                    "id": "#cluster_blastp_wnode.cwl/no_merge"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "-nogenbank"
                    },
                    "id": "#cluster_blastp_wnode.cwl/nogenbank"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-ofmt"
                    },
                    "id": "#cluster_blastp_wnode.cwl/ofmt"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "output",
                    "inputBinding": {
                        "prefix": "-O"
                    },
                    "id": "#cluster_blastp_wnode.cwl/output_dir"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#cluster_blastp_wnode.cwl/proteins"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-seg"
                    },
                    "id": "#cluster_blastp_wnode.cwl/seg"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "-soft_masking"
                    },
                    "id": "#cluster_blastp_wnode.cwl/soft_masking"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-threshold"
                    },
                    "id": "#cluster_blastp_wnode.cwl/threshold"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-top-by-score"
                    },
                    "id": "#cluster_blastp_wnode.cwl/top_by_score"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "-word_size"
                    },
                    "id": "#cluster_blastp_wnode.cwl/word_size"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-workers"
                    },
                    "id": "#cluster_blastp_wnode.cwl/workers"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "prefix": "-workers-per-cpu"
                    },
                    "id": "#cluster_blastp_wnode.cwl/workers_per_cpu"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.output_dir)"
                    },
                    "id": "#cluster_blastp_wnode.cwl/outdir"
                }
            ],
            "id": "#cluster_blastp_wnode.cwl"
        },
        {
            "label": "gpx_qdump",
            "class": "CommandLineTool",
            "baseCommand": "gpx_qdump",
            "inputs": [
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "-input-path"
                    },
                    "id": "#gpx_qdump.cwl/input_path"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "output.asn",
                    "inputBinding": {
                        "prefix": "-output"
                    },
                    "id": "#gpx_qdump.cwl/output_name"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-unzip"
                    },
                    "id": "#gpx_qdump.cwl/unzip"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_name)"
                    },
                    "id": "#gpx_qdump.cwl/output"
                }
            ],
            "id": "#gpx_qdump.cwl"
        },
        {
            "label": "gpx_qsubmit",
            "doc": "This workflow is specialized for the case when there is an LDS2 input  LDS2 is a _reference_ object, the kind that CWL does not like we need to provide actual input: proteins which matches the name of ASN.1 object references in LDS2 Another limitation is that it can handle no more than two item arrays in blastdb_dir and asn_cache Workaround used so far: in:\n  proteins:\n    default:\n        class: File\n        path: '/dev/null'\n        basename: 'null'\n        contents: ''\n",
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entry": "$(inputs.proteins)",
                            "writable": false
                        },
                        {
                            "entry": "${ var cs=0; var s=inputs.blastdb_dir.length-1; var as = cs; if(as >= s) {as = s }; return inputs.blastdb_dir[as]; }",
                            "writable": false
                        },
                        {
                            "entry": "${ var cs=1; var s=inputs.blastdb_dir.length-1; var as = cs; if(as >= s) {as = s }; return inputs.blastdb_dir[as]; }",
                            "writable": false
                        },
                        {
                            "entry": "${ var cs=0; var s=inputs.asn_cache.length-1; var as = cs; if(as >= s) {as = s }; return inputs.asn_cache[as]; }",
                            "writable": false
                        },
                        {
                            "entry": "${ var cs=1; var s=inputs.asn_cache.length-1; var as = cs; if(as >= s) {as = s }; return inputs.asn_cache[as]; }",
                            "writable": false
                        },
                        {
                            "entryname": "ids.mft",
                            "entry": "${var blob = '# ids.mft created for gpx_qsubmit from input ids Array of Files\\n';for (var i = 0; i < inputs.ids.length; i++) {blob += inputs.ids[i].path  + '\\n';}return blob;}"
                        }
                    ]
                }
            ],
            "baseCommand": "gpx_qsubmit",
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-NxM-threshold"
                    },
                    "id": "#gpx_qsubmit.cwl/NxM_threshold"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "subject",
                    "inputBinding": {
                        "prefix": "-affinity"
                    },
                    "id": "#gpx_qsubmit.cwl/affinity"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "Directory"
                        }
                    ],
                    "inputBinding": {
                        "prefix": "-asn-cache",
                        "itemSeparator": ","
                    },
                    "id": "#gpx_qsubmit.cwl/asn_cache"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-batch-size"
                    },
                    "id": "#gpx_qsubmit.cwl/batch_size"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "prefix": "-db",
                        "valueFrom": "${ var blob = ''; for (var i = 0; i < inputs.blastdb_dir.length; i++) { blob += inputs.blastdb_dir[i].path + '/' + inputs.blastdb[i]; if(i != inputs.blastdb_dir.length-1) blob += ','; } return blob; }"
                    },
                    "id": "#gpx_qsubmit.cwl/blastdb"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "Directory"
                        }
                    ],
                    "id": "#gpx_qsubmit.cwl/blastdb_dir"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "id": "#gpx_qsubmit.cwl/ids"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "ids.mft",
                    "inputBinding": {
                        "prefix": "-ids-manifest"
                    },
                    "id": "#gpx_qsubmit.cwl/ids_manifest"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-lds2"
                    },
                    "id": "#gpx_qsubmit.cwl/lds2"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-max-batch-length"
                    },
                    "id": "#gpx_qsubmit.cwl/max_batch_length"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": null,
                    "id": "#gpx_qsubmit.cwl/nogenbank"
                },
                {
                    "type": "string",
                    "default": "jobs.xml",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#gpx_qsubmit.cwl/output_xml_jobs"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-overlap"
                    },
                    "id": "#gpx_qsubmit.cwl/overlap"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#gpx_qsubmit.cwl/proteins"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-queries-gc-id-list"
                    },
                    "id": "#gpx_qsubmit.cwl/queries_gc_id_list"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-subjects-gc-id-list"
                    },
                    "id": "#gpx_qsubmit.cwl/subjects_gc_id_list"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-subseq-size"
                    },
                    "id": "#gpx_qsubmit.cwl/subseq_size"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-xml-jobs"
                    },
                    "id": "#gpx_qsubmit.cwl/xml_jobs"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_xml_jobs)"
                    },
                    "id": "#gpx_qsubmit.cwl/jobs"
                }
            ],
            "id": "#gpx_qsubmit.cwl"
        },
        {
            "label": "set_operation",
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "A.mft",
                            "entry": "${var blob = '# A.mft created for set_operation from input A Array of Files\\n'; for (var i = 0; i < inputs.A.length; i++) { blob += inputs.A[i].path + '\\n'; } return blob; }"
                        },
                        {
                            "entryname": "B.mft",
                            "entry": "${var blob = '# B.mft created for set_operation from input B Array of Files\\n'; for (var i = 0; i < inputs.B.length; i++) { blob += inputs.B[i].path + '\\n'; } return blob; }"
                        }
                    ]
                }
            ],
            "baseCommand": "set_operation",
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#set_operation.cwl/A"
                },
                {
                    "type": "string",
                    "default": "A.mft",
                    "inputBinding": {
                        "prefix": "-A-manifest"
                    },
                    "id": "#set_operation.cwl/A_impl"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#set_operation.cwl/B"
                },
                {
                    "type": "string",
                    "default": "B.mft",
                    "inputBinding": {
                        "prefix": "-B-manifest"
                    },
                    "id": "#set_operation.cwl/B_impl"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-operation"
                    },
                    "id": "#set_operation.cwl/operation"
                },
                {
                    "type": "string",
                    "default": "result.lst",
                    "inputBinding": {
                        "prefix": "-output"
                    },
                    "id": "#set_operation.cwl/output_impl"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_impl)"
                    },
                    "id": "#set_operation.cwl/output"
                }
            ],
            "id": "#set_operation.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "file concatenation",
            "baseCommand": "cat",
            "stdout": "cat.out",
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#cat_array_of_files.cwl/files_in"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#cat_array_of_files.cwl/file_out",
                    "outputBinding": {
                        "glob": "cat.out"
                    }
                }
            ],
            "id": "#cat_array_of_files.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "cwl split wrapper",
            "baseCommand": "split",
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-l"
                    },
                    "id": "#split.cwl/chunk_size"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#split.cwl/input"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "jobs",
                    "inputBinding": {
                        "position": 5,
                        "valueFrom": "$(inputs.mask)"
                    },
                    "id": "#split.cwl/mask"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-n l//",
                        "separate": false
                    },
                    "id": "#split.cwl/nchunks"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": ".xml",
                    "inputBinding": {
                        "position": 3,
                        "separate": false,
                        "prefix": "--additional-suffix="
                    },
                    "id": "#split.cwl/suffix"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "$(inputs.mask)?*$(inputs.suffix)"
                    },
                    "id": "#split.cwl/jobs"
                }
            ],
            "id": "#split.cwl"
        },
        {
            "label": "blastp_wnode_naming",
            "class": "Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#tt_blastp_wnode_naming.cwl/affinity"
                },
                {
                    "type": "string",
                    "id": "#tt_blastp_wnode_naming.cwl/align_filter"
                },
                {
                    "type": "boolean",
                    "id": "#tt_blastp_wnode_naming.cwl/allow_intersection"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "Directory"
                    },
                    "id": "#tt_blastp_wnode_naming.cwl/asn_cache"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#tt_blastp_wnode_naming.cwl/batch-size"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#tt_blastp_wnode_naming.cwl/blastdb"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "Directory"
                    },
                    "id": "#tt_blastp_wnode_naming.cwl/blastdb_dir"
                },
                {
                    "type": "string",
                    "id": "#tt_blastp_wnode_naming.cwl/comp_based_stats"
                },
                {
                    "type": "boolean",
                    "id": "#tt_blastp_wnode_naming.cwl/compart"
                },
                {
                    "type": "string",
                    "id": "#tt_blastp_wnode_naming.cwl/dbsize"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "id": "#tt_blastp_wnode_naming.cwl/evalue"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#tt_blastp_wnode_naming.cwl/extra_coverage"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#tt_blastp_wnode_naming.cwl/ids"
                },
                {
                    "type": "File",
                    "id": "#tt_blastp_wnode_naming.cwl/lds2"
                },
                {
                    "type": "int",
                    "id": "#tt_blastp_wnode_naming.cwl/max_batch_length"
                },
                {
                    "type": "int",
                    "id": "#tt_blastp_wnode_naming.cwl/max_jobs"
                },
                {
                    "type": "int",
                    "id": "#tt_blastp_wnode_naming.cwl/max_target_seqs"
                },
                {
                    "type": "boolean",
                    "id": "#tt_blastp_wnode_naming.cwl/no_merge"
                },
                {
                    "type": "boolean",
                    "id": "#tt_blastp_wnode_naming.cwl/nogenbank"
                },
                {
                    "type": "string",
                    "id": "#tt_blastp_wnode_naming.cwl/ofmt"
                },
                {
                    "type": "File",
                    "id": "#tt_blastp_wnode_naming.cwl/proteins"
                },
                {
                    "type": "string",
                    "id": "#tt_blastp_wnode_naming.cwl/scatter_gather_nchunks"
                },
                {
                    "type": "string",
                    "id": "#tt_blastp_wnode_naming.cwl/seg"
                },
                {
                    "type": "int",
                    "id": "#tt_blastp_wnode_naming.cwl/threshold"
                },
                {
                    "type": "int",
                    "id": "#tt_blastp_wnode_naming.cwl/top_by_score"
                },
                {
                    "type": "int",
                    "id": "#tt_blastp_wnode_naming.cwl/word_size"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#tt_blastp_wnode_naming.cwl/collect_aligns/file_out",
                    "id": "#tt_blastp_wnode_naming.cwl/blast_align"
                }
            ],
            "steps": [
                {
                    "run": "#tt_cluster_and_qdump.cwl",
                    "scatter": "#tt_blastp_wnode_naming.cwl/cluster_and_qdump/input_jobs",
                    "in": [
                        {
                            "source": "#tt_blastp_wnode_naming.cwl/align_filter",
                            "id": "#tt_blastp_wnode_naming.cwl/cluster_and_qdump/align_filter"
                        },
                        {
                            "source": "#tt_blastp_wnode_naming.cwl/allow_intersection",
                            "id": "#tt_blastp_wnode_naming.cwl/cluster_and_qdump/allow_intersection"
                        },
                        {
                            "source": "#tt_blastp_wnode_naming.cwl/asn_cache",
                            "id": "#tt_blastp_wnode_naming.cwl/cluster_and_qdump/asn_cache"
                        },
                        {
                            "source": "#tt_blastp_wnode_naming.cwl/blastdb_dir",
                            "id": "#tt_blastp_wnode_naming.cwl/cluster_and_qdump/blastdb_dir"
                        },
                        {
                            "source": "#tt_blastp_wnode_naming.cwl/comp_based_stats",
                            "id": "#tt_blastp_wnode_naming.cwl/cluster_and_qdump/comp_based_stats"
                        },
                        {
                            "source": "#tt_blastp_wnode_naming.cwl/compart",
                            "id": "#tt_blastp_wnode_naming.cwl/cluster_and_qdump/compart"
                        },
                        {
                            "source": "#tt_blastp_wnode_naming.cwl/dbsize",
                            "id": "#tt_blastp_wnode_naming.cwl/cluster_and_qdump/dbsize"
                        },
                        {
                            "source": "#tt_blastp_wnode_naming.cwl/evalue",
                            "id": "#tt_blastp_wnode_naming.cwl/cluster_and_qdump/evalue"
                        },
                        {
                            "source": "#tt_blastp_wnode_naming.cwl/extra_coverage",
                            "id": "#tt_blastp_wnode_naming.cwl/cluster_and_qdump/extra_coverage"
                        },
                        {
                            "source": "#tt_blastp_wnode_naming.cwl/split_jobs/jobs",
                            "id": "#tt_blastp_wnode_naming.cwl/cluster_and_qdump/input_jobs"
                        },
                        {
                            "source": "#tt_blastp_wnode_naming.cwl/lds2",
                            "id": "#tt_blastp_wnode_naming.cwl/cluster_and_qdump/lds2"
                        },
                        {
                            "source": "#tt_blastp_wnode_naming.cwl/max_jobs",
                            "id": "#tt_blastp_wnode_naming.cwl/cluster_and_qdump/max_jobs"
                        },
                        {
                            "source": "#tt_blastp_wnode_naming.cwl/max_target_seqs",
                            "id": "#tt_blastp_wnode_naming.cwl/cluster_and_qdump/max_target_seqs"
                        },
                        {
                            "source": "#tt_blastp_wnode_naming.cwl/no_merge",
                            "id": "#tt_blastp_wnode_naming.cwl/cluster_and_qdump/no_merge"
                        },
                        {
                            "source": "#tt_blastp_wnode_naming.cwl/nogenbank",
                            "id": "#tt_blastp_wnode_naming.cwl/cluster_and_qdump/nogenbank"
                        },
                        {
                            "source": "#tt_blastp_wnode_naming.cwl/ofmt",
                            "id": "#tt_blastp_wnode_naming.cwl/cluster_and_qdump/ofmt"
                        },
                        {
                            "source": "#tt_blastp_wnode_naming.cwl/proteins",
                            "id": "#tt_blastp_wnode_naming.cwl/cluster_and_qdump/proteins"
                        },
                        {
                            "source": "#tt_blastp_wnode_naming.cwl/seg",
                            "id": "#tt_blastp_wnode_naming.cwl/cluster_and_qdump/seg"
                        },
                        {
                            "source": "#tt_blastp_wnode_naming.cwl/threshold",
                            "id": "#tt_blastp_wnode_naming.cwl/cluster_and_qdump/threshold"
                        },
                        {
                            "source": "#tt_blastp_wnode_naming.cwl/top_by_score",
                            "id": "#tt_blastp_wnode_naming.cwl/cluster_and_qdump/top_by_score"
                        },
                        {
                            "source": "#tt_blastp_wnode_naming.cwl/word_size",
                            "id": "#tt_blastp_wnode_naming.cwl/cluster_and_qdump/word_size"
                        }
                    ],
                    "out": [
                        "#tt_blastp_wnode_naming.cwl/cluster_and_qdump/blast_align"
                    ],
                    "id": "#tt_blastp_wnode_naming.cwl/cluster_and_qdump"
                },
                {
                    "run": "#cat_array_of_files.cwl",
                    "in": [
                        {
                            "source": "#tt_blastp_wnode_naming.cwl/cluster_and_qdump/blast_align",
                            "id": "#tt_blastp_wnode_naming.cwl/collect_aligns/files_in"
                        }
                    ],
                    "out": [
                        "#tt_blastp_wnode_naming.cwl/collect_aligns/file_out"
                    ],
                    "id": "#tt_blastp_wnode_naming.cwl/collect_aligns"
                },
                {
                    "run": "#gpx_qsubmit.cwl",
                    "in": [
                        {
                            "source": "#tt_blastp_wnode_naming.cwl/affinity",
                            "id": "#tt_blastp_wnode_naming.cwl/gpx_qsubmit/affinity"
                        },
                        {
                            "source": "#tt_blastp_wnode_naming.cwl/asn_cache",
                            "id": "#tt_blastp_wnode_naming.cwl/gpx_qsubmit/asn_cache"
                        },
                        {
                            "source": "#tt_blastp_wnode_naming.cwl/batch-size",
                            "id": "#tt_blastp_wnode_naming.cwl/gpx_qsubmit/batch_size"
                        },
                        {
                            "source": "#tt_blastp_wnode_naming.cwl/blastdb",
                            "id": "#tt_blastp_wnode_naming.cwl/gpx_qsubmit/blastdb"
                        },
                        {
                            "source": "#tt_blastp_wnode_naming.cwl/blastdb_dir",
                            "id": "#tt_blastp_wnode_naming.cwl/gpx_qsubmit/blastdb_dir"
                        },
                        {
                            "source": "#tt_blastp_wnode_naming.cwl/ids",
                            "id": "#tt_blastp_wnode_naming.cwl/gpx_qsubmit/ids"
                        },
                        {
                            "source": "#tt_blastp_wnode_naming.cwl/lds2",
                            "id": "#tt_blastp_wnode_naming.cwl/gpx_qsubmit/lds2"
                        },
                        {
                            "source": "#tt_blastp_wnode_naming.cwl/max_batch_length",
                            "id": "#tt_blastp_wnode_naming.cwl/gpx_qsubmit/max_batch_length"
                        },
                        {
                            "source": "#tt_blastp_wnode_naming.cwl/nogenbank",
                            "id": "#tt_blastp_wnode_naming.cwl/gpx_qsubmit/nogenbank"
                        },
                        {
                            "source": "#tt_blastp_wnode_naming.cwl/proteins",
                            "id": "#tt_blastp_wnode_naming.cwl/gpx_qsubmit/proteins"
                        }
                    ],
                    "out": [
                        "#tt_blastp_wnode_naming.cwl/gpx_qsubmit/jobs"
                    ],
                    "id": "#tt_blastp_wnode_naming.cwl/gpx_qsubmit"
                },
                {
                    "run": "#split.cwl",
                    "in": [
                        {
                            "source": "#tt_blastp_wnode_naming.cwl/gpx_qsubmit/jobs",
                            "id": "#tt_blastp_wnode_naming.cwl/split_jobs/input"
                        },
                        {
                            "source": "#tt_blastp_wnode_naming.cwl/scatter_gather_nchunks",
                            "id": "#tt_blastp_wnode_naming.cwl/split_jobs/nchunks"
                        }
                    ],
                    "out": [
                        "#tt_blastp_wnode_naming.cwl/split_jobs/jobs"
                    ],
                    "id": "#tt_blastp_wnode_naming.cwl/split_jobs"
                }
            ],
            "id": "#tt_blastp_wnode_naming.cwl"
        },
        {
            "class": "Workflow",
            "label": "cluster_blastp_wnode and gpx_qdump combined",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#tt_cluster_and_qdump.cwl/align_filter"
                },
                {
                    "type": "boolean",
                    "id": "#tt_cluster_and_qdump.cwl/allow_intersection"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "Directory"
                    },
                    "id": "#tt_cluster_and_qdump.cwl/asn_cache"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "Directory"
                    },
                    "id": "#tt_cluster_and_qdump.cwl/blastdb_dir"
                },
                {
                    "type": "string",
                    "id": "#tt_cluster_and_qdump.cwl/comp_based_stats"
                },
                {
                    "type": "boolean",
                    "id": "#tt_cluster_and_qdump.cwl/compart"
                },
                {
                    "type": "string",
                    "id": "#tt_cluster_and_qdump.cwl/dbsize"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "id": "#tt_cluster_and_qdump.cwl/evalue"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#tt_cluster_and_qdump.cwl/extra_coverage"
                },
                {
                    "type": "File",
                    "id": "#tt_cluster_and_qdump.cwl/input_jobs"
                },
                {
                    "type": "File",
                    "id": "#tt_cluster_and_qdump.cwl/lds2"
                },
                {
                    "type": "int",
                    "id": "#tt_cluster_and_qdump.cwl/max_jobs"
                },
                {
                    "type": "int",
                    "id": "#tt_cluster_and_qdump.cwl/max_target_seqs"
                },
                {
                    "type": "boolean",
                    "id": "#tt_cluster_and_qdump.cwl/no_merge"
                },
                {
                    "type": "boolean",
                    "id": "#tt_cluster_and_qdump.cwl/nogenbank"
                },
                {
                    "type": "string",
                    "id": "#tt_cluster_and_qdump.cwl/ofmt"
                },
                {
                    "type": "File",
                    "id": "#tt_cluster_and_qdump.cwl/proteins"
                },
                {
                    "type": "string",
                    "id": "#tt_cluster_and_qdump.cwl/seg"
                },
                {
                    "type": "int",
                    "id": "#tt_cluster_and_qdump.cwl/threshold"
                },
                {
                    "type": "int",
                    "id": "#tt_cluster_and_qdump.cwl/top_by_score"
                },
                {
                    "type": "int",
                    "id": "#tt_cluster_and_qdump.cwl/word_size"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#tt_cluster_and_qdump.cwl/gpx_qdump/output",
                    "id": "#tt_cluster_and_qdump.cwl/blast_align"
                }
            ],
            "steps": [
                {
                    "run": "#cluster_blastp_wnode.cwl",
                    "in": [
                        {
                            "source": "#tt_cluster_and_qdump.cwl/align_filter",
                            "id": "#tt_cluster_and_qdump.cwl/cluster_blastp_wnode/align_filter"
                        },
                        {
                            "source": "#tt_cluster_and_qdump.cwl/allow_intersection",
                            "id": "#tt_cluster_and_qdump.cwl/cluster_blastp_wnode/allow_intersection"
                        },
                        {
                            "source": "#tt_cluster_and_qdump.cwl/asn_cache",
                            "id": "#tt_cluster_and_qdump.cwl/cluster_blastp_wnode/asn_cache"
                        },
                        {
                            "source": "#tt_cluster_and_qdump.cwl/blastdb_dir",
                            "id": "#tt_cluster_and_qdump.cwl/cluster_blastp_wnode/blastdb_dir"
                        },
                        {
                            "source": "#tt_cluster_and_qdump.cwl/comp_based_stats",
                            "id": "#tt_cluster_and_qdump.cwl/cluster_blastp_wnode/comp_based_stats"
                        },
                        {
                            "source": "#tt_cluster_and_qdump.cwl/compart",
                            "id": "#tt_cluster_and_qdump.cwl/cluster_blastp_wnode/compart"
                        },
                        {
                            "source": "#tt_cluster_and_qdump.cwl/dbsize",
                            "id": "#tt_cluster_and_qdump.cwl/cluster_blastp_wnode/dbsize"
                        },
                        {
                            "source": "#tt_cluster_and_qdump.cwl/evalue",
                            "id": "#tt_cluster_and_qdump.cwl/cluster_blastp_wnode/evalue"
                        },
                        {
                            "source": "#tt_cluster_and_qdump.cwl/extra_coverage",
                            "id": "#tt_cluster_and_qdump.cwl/cluster_blastp_wnode/extra_coverage"
                        },
                        {
                            "source": "#tt_cluster_and_qdump.cwl/input_jobs",
                            "id": "#tt_cluster_and_qdump.cwl/cluster_blastp_wnode/input_jobs"
                        },
                        {
                            "source": "#tt_cluster_and_qdump.cwl/lds2",
                            "id": "#tt_cluster_and_qdump.cwl/cluster_blastp_wnode/lds2"
                        },
                        {
                            "source": "#tt_cluster_and_qdump.cwl/max_jobs",
                            "id": "#tt_cluster_and_qdump.cwl/cluster_blastp_wnode/max_jobs"
                        },
                        {
                            "source": "#tt_cluster_and_qdump.cwl/max_target_seqs",
                            "id": "#tt_cluster_and_qdump.cwl/cluster_blastp_wnode/max_target_seqs"
                        },
                        {
                            "source": "#tt_cluster_and_qdump.cwl/no_merge",
                            "id": "#tt_cluster_and_qdump.cwl/cluster_blastp_wnode/no_merge"
                        },
                        {
                            "source": "#tt_cluster_and_qdump.cwl/nogenbank",
                            "id": "#tt_cluster_and_qdump.cwl/cluster_blastp_wnode/nogenbank"
                        },
                        {
                            "source": "#tt_cluster_and_qdump.cwl/ofmt",
                            "id": "#tt_cluster_and_qdump.cwl/cluster_blastp_wnode/ofmt"
                        },
                        {
                            "source": "#tt_cluster_and_qdump.cwl/proteins",
                            "id": "#tt_cluster_and_qdump.cwl/cluster_blastp_wnode/proteins"
                        },
                        {
                            "source": "#tt_cluster_and_qdump.cwl/seg",
                            "id": "#tt_cluster_and_qdump.cwl/cluster_blastp_wnode/seg"
                        },
                        {
                            "source": "#tt_cluster_and_qdump.cwl/threshold",
                            "id": "#tt_cluster_and_qdump.cwl/cluster_blastp_wnode/threshold"
                        },
                        {
                            "source": "#tt_cluster_and_qdump.cwl/top_by_score",
                            "id": "#tt_cluster_and_qdump.cwl/cluster_blastp_wnode/top_by_score"
                        },
                        {
                            "source": "#tt_cluster_and_qdump.cwl/word_size",
                            "id": "#tt_cluster_and_qdump.cwl/cluster_blastp_wnode/word_size"
                        },
                        {
                            "default": 1.0,
                            "id": "#tt_cluster_and_qdump.cwl/cluster_blastp_wnode/workers_per_cpu"
                        }
                    ],
                    "out": [
                        "#tt_cluster_and_qdump.cwl/cluster_blastp_wnode/outdir"
                    ],
                    "id": "#tt_cluster_and_qdump.cwl/cluster_blastp_wnode"
                },
                {
                    "run": "#gpx_qdump.cwl",
                    "in": [
                        {
                            "source": "#tt_cluster_and_qdump.cwl/cluster_blastp_wnode/outdir",
                            "id": "#tt_cluster_and_qdump.cwl/gpx_qdump/input_path"
                        },
                        {
                            "default": "*",
                            "id": "#tt_cluster_and_qdump.cwl/gpx_qdump/unzip"
                        }
                    ],
                    "out": [
                        "#tt_cluster_and_qdump.cwl/gpx_qdump/output"
                    ],
                    "id": "#tt_cluster_and_qdump.cwl/gpx_qdump"
                }
            ],
            "id": "#tt_cluster_and_qdump.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
